==> magento-module-shared-catalog-100.1.7-p1.zip: Test/Unit/Controller/Adminhtml/SharedCatalog/AbstractMassActionTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\SharedCatalog\Test\Unit\Controller\Adminhtml\SharedCatalog;

use Magento\Framework\Controller\ResultFactory;

/**
 * Class AbstractMassActionTest
 * @package Magento\SharedCatalog\Test\Unit\Controller\Adminhtml\SharedCatalog
 */
class AbstractMassActionTest extends \PHPUnit\Framework\TestCase
{
    /** @var \Magento\Backend\App\Action\Context|\PHPUnit\Framework\MockObject\MockObject*/
    protected $context;

    /** @var \Magento\Ui\Component\MassAction\Filter|\PHPUnit\Framework\MockObject\MockObject */
    protected $filter;

    /** @var \Magento\SharedCatalog\Model\ResourceModel\SharedCatalog\CollectionFactory
     * |\PHPUnit\Framework\MockObject\MockObject */
    protected $collectionFactory;

    /** @var \Psr\Log\LoggerInterface|\PHPUnit\Framework\MockObject\MockObject */
    protected $logger;

    /** @var \Magento\Framework\TestFramework\Unit\Helper\ObjectManager */
    protected $objectManagerHelper;

    /** @var \Magento\SharedCatalog\Controller\Adminhtml\SharedCatalog\AbstractMassAction */
    protected $abstractMassAction;

    protected function setUp(): void
    {
        $this->context = $this->createPartialMock(
            \Magento\Backend\App\Action\Context::class,
            ['getMessageManager', 'getResultFactory']
        );
        $this->filter = $this->createPartialMock(\Magento\Ui\Component\MassAction\Filter::class, ['getCollection']);
        $this->collectionFactory = $this->createPartialMock(
            \Magento\SharedCatalog\Model\ResourceModel\SharedCatalog\CollectionFactory::class,
            ['create']
        );
        $this->logger = $this->getMockForAbstractClass(
            \Psr\Log\LoggerInterface::class,
            [],
            '',
            false,
            false,
            true,
            ['critical']
        );
    }

    /**
     * Test for method Execute
     */
    public function testExecute()
    {
        $collection = $this->createMock(\Magento\Framework\Data\Collection\AbstractDb::class);
        $filteredCollection = $this->getMockForAbstractClass(
            \Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection::class,
            [],
            '',
            false
        );

        $this->collectionFactory->expects($this->once())
            ->method('create')
            ->willReturn($collection);

        $this->filter->expects($this->once())
            ->method('getCollection')
            ->with($collection)
            ->willReturn($filteredCollection);

        $this->abstractMassAction = $this->getMockForAbstractClass(
            \Magento\SharedCatalog\Controller\Adminhtml\SharedCatalog\AbstractMassAction::class,
            [
                $this->context,
                $this->filter,
                $this->collectionFactory,
                $this->logger,
            ],
            '',
            true,
            false,
            true,
            []
        );

        $this->abstractMassAction->expects($this->once())
            ->method('massAction')
            ->with($filteredCollection);

        $result = $this->abstractMassAction->execute();
        $this->assertNull($result);
    }

    /**
     * Test for method Execute
     */
    public function testExecuteException()
    {
        $sampleResult = 'sample result';
        $message = 'An Error has occured';
        $exception = new \Exception($message);
        $messageManager = $this->getMockForAbstractClass(
            \Magento\Framework\Message\ManagerInterface::class,
            [],
            '',
            false,
            false,
            true,
            ['addError']
        );
        $this->context->expects($this->any())
            ->method('getMessageManager')
            ->willReturn($messageManager);
        $this->collectionFactory->expects($this->once())
            ->method('create')
            ->will($this->throwException($exception));
        $messageManager->expects($this->once())
            ->method('addError')
            ->with($message);
        $this->logger->expects($this->once())
            ->method('critical')
            ->with($exception);

        $resultRedirect = $this->createPartialMock(\Magento\Backend\Model\View\Result\Redirect::class, ['setPath']);
        $resultRedirect->expects($this->any())
            ->method('setPath')
            ->willReturn($sampleResult);

        $resultFactory = $this->createPartialMock(\Magento\Framework\Controller\ResultFactory::class, ['create']);
        $resultFactory->expects($this->any())
            ->method('create')
            ->with(ResultFactory::TYPE_REDIRECT)
            ->willReturn($resultRedirect);

        $this->context->expects($this->any())
            ->method('getResultFactory')
            ->willReturn($resultFactory);

        $this->abstractMassAction = $this->getMockForAbstractClass(
            \Magento\SharedCatalog\Controller\Adminhtml\SharedCatalog\AbstractMassAction::class,
            [
                $this->context,
                $this->filter,
                $this->collectionFactory,
                $this->logger,
            ],
            '',
            true,
            false,
            true,
            []
        );

        $result = $this->abstractMassAction->execute();
        $this->assertEquals($sampleResult, $result);
    }
}

==> magento-module-shared-catalog-100.3.4-p12.zip: Test/Unit/Controller/Adminhtml/SharedCatalog/AbstractMassActionTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\SharedCatalog\Test\Unit\Controller\Adminhtml\SharedCatalog;

use Magento\Backend\App\Action\Context;
use Magento\Backend\Model\View\Result\Redirect;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Data\Collection\AbstractDb;
use Magento\Framework\Message\ManagerInterface;
use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;
use Magento\Framework\TestFramework\Unit\Helper\ObjectManager;
use Magento\SharedCatalog\Controller\Adminhtml\SharedCatalog\AbstractMassAction;
use Magento\SharedCatalog\Model\ResourceModel\SharedCatalog\CollectionFactory;
use Magento\Ui\Component\MassAction\Filter;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Psr\Log\LoggerInterface;

/**
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class AbstractMassActionTest extends TestCase
{
    /** @var Context|MockObject*/
    protected $context;

    /** @var Filter|MockObject */
    protected $filter;

    /** @var CollectionFactory|MockObject */
    protected $collectionFactory;

    /** @var LoggerInterface|MockObject */
    protected $logger;

    /** @var ObjectManager */
    protected $objectManagerHelper;

    /** @var AbstractMassAction */
    protected $abstractMassAction;

    protected function setUp(): void
    {
        $this->context = $this->createPartialMock(
            Context::class,
            ['getMessageManager', 'getResultFactory']
        );
        $this->filter = $this->createPartialMock(Filter::class, ['getCollection']);
        $this->collectionFactory = $this->createPartialMock(
            CollectionFactory::class,
            ['create']
        );
        $this->logger = $this->getMockForAbstractClass(
            LoggerInterface::class,
            [],
            '',
            false,
            false,
            true,
            ['critical']
        );
    }

    /**
     * Test for method Execute
     */
    public function testExecute()
    {
        $collection = $this->createMock(AbstractDb::class);
        $filteredCollection = $this->getMockForAbstractClass(
            AbstractCollection::class,
            [],
            '',
            false
        );

        $this->collectionFactory->expects($this->once())
            ->method('create')
            ->willReturn($collection);

        $this->filter->expects($this->once())
            ->method('getCollection')
            ->with($collection)
            ->willReturn($filteredCollection);

        $this->abstractMassAction = $this->getMockForAbstractClass(
            AbstractMassAction::class,
            [
                $this->context,
                $this->filter,
                $this->collectionFactory,
                $this->logger,
            ],
            '',
            true,
            false,
            true,
            []
        );

        $this->abstractMassAction->expects($this->once())
            ->method('massAction')
            ->with($filteredCollection);

        $result = $this->abstractMassAction->execute();
        $this->assertNull($result);
    }

    /**
     * Test for method Execute
     */
    public function testExecuteException()
    {
        $sampleResult = 'sample result';
        $message = 'An Error has occured';
        $exception = new \Exception($message);
        $messageManager = $this->getMockForAbstractClass(
            ManagerInterface::class,
            [],
            '',
            false,
            false,
            true,
            ['addError']
        );
        $this->context->expects($this->any())
            ->method('getMessageManager')
            ->willReturn($messageManager);
        $this->collectionFactory->expects($this->once())
            ->method('create')
            ->willThrowException($exception);
        $messageManager->expects($this->once())
            ->method('addError')
            ->with($message);
        $this->logger->expects($this->once())
            ->method('critical')
            ->with($exception);

        $resultRedirect = $this->createPartialMock(Redirect::class, ['setPath']);
        $resultRedirect->expects($this->any())
            ->method('setPath')
            ->willReturn($sampleResult);

        $resultFactory = $this->createPartialMock(ResultFactory::class, ['create']);
        $resultFactory->expects($this->any())
            ->method('create')
            ->with(ResultFactory::TYPE_REDIRECT)
            ->willReturn($resultRedirect);

        $this->context->expects($this->any())
            ->method('getResultFactory')
            ->willReturn($resultFactory);

        $this->abstractMassAction = $this->getMockForAbstractClass(
            AbstractMassAction::class,
            [
                $this->context,
                $this->filter,
                $this->collectionFactory,
                $this->logger,
            ],
            '',
            true,
            false,
            true,
            []
        );

        $result = $this->abstractMassAction->execute();
        $this->assertEquals($sampleResult, $result);
    }
}
